@@ -7,17 +7,16 @@ use warnings;
 
 use Venus::Role 'with';
 
-with 'Venus::Role::Valuable';
-with 'Venus::Role::Buildable';
+# AUDITS
 
-# BUILDERS
+sub AUDIT {
+  my ($self, $from) = @_;
 
-sub build_arg {
-  my ($self, $data) = @_;
+  if (!$from->does('Venus::Role::Valuable')) {
+    die "${self} requires ${from} to consume Venus::Role::Valuable";
+  }
 
-  return {
-    value => $data,
-  };
+  return $self;
 }
 
 # METHODS
@@ -37,7 +36,7 @@ sub set {
 # EXPORTS
 
 sub EXPORT {
-  ['BUILDARGS', 'build_arg', 'default', 'get', 'set', 'value']
+  ['get', 'set']
 }
 
 1;
@@ -62,11 +61,12 @@ Accessible Role for Perl 5
 
   use Venus::Class;
 
+  with 'Venus::Role::Valuable';
   with 'Venus::Role::Accessible';
 
   package main;
 
-  my $example = Example->new('hello, there');
+  my $example = Example->new(value => 'hello, there');
 
 =cut
 
@@ -77,16 +77,6 @@ as well as C<get> and C<set> methods for modifying the value.
 
 =cut
 
-=head1 INTEGRATES
-
-This package integrates behaviors from:
-
-L<Venus::Role::Buildable>
-
-L<Venus::Role::Valuable>
-
-=cut
-
 =head1 METHODS
 
 This package provides the following methods:
